%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%
%%% Tiny Vector Matrix Library
%%% Dense Vector Matrix Libary of Tiny size using Expression Templates
%%%
%%% Copyright (C) 2001, 2002 Olaf Petzold <opetzold@wit.regiocom.net>
%%%
%%% This library is free software; you can redistribute it and/or
%%% modify it under the terms of the GNU Lesser General Public
%%% License as published by the Free Software Foundation; either
%%% version 2.1 of the License, or (at your option) any later version.
%%%
%%% This library is distributed in the hope that it will be useful,
%%% but WITHOUT ANY WARRANTY; without even the implied warranty of
%%% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
%%% Lesser General Public License for more details.
%%%
%%% You should have received a copy of the GNU Lesser General Public
%%% License along with this library; if not, write to the Free Software
%%% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
%%%
%%% $Id: benchmark.m,v 1.4 2003/03/01 10:25:21 opetzold Exp $
%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% load benchmark results
tvmet
blitz
ublas
mtl
stl
peak

% prepare plot
grid "on";
xlabel("Dimension");
ylabel("MFlops/s");

x_lo = 1;
x_up = 15;
y_lo = 0;
y_up = 2500;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% plot vector addition operation benchmark
gset output "bench_vector_add.png";
gset terminal x11
title("vector addition");
gplot [x_lo:x_up][y_lo:y_up] \
      tvmet_vector_add with lines title "tvmet", \
      blitz_vector_add with lines title "blitz++", \
      ublas_vector_add with lines title "uBLAS", \
      mtl_vector_add with lines title "MTL", \
      stl_vector_add with lines title "STL", \
      peak_scalar_add with linespoint '+' title "peak Add", \
      peak_scalar_mul with linespoint '*' title "peak Mul"
pause (1);
gset terminal png small color;
replot;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% plot vector inner benchmark
gset output "bench_vector_inner_product.png";
gset terminal x11
title("vector inner (dot) product");
gplot [x_lo:x_up][y_lo:y_up] \
      tvmet_vector_inner_product with lines title "tvmet", \
      blitz_vector_inner_product with lines title "blitz++", \
      ublas_vector_inner_product with lines title "uBLAS", \
      mtl_vector_inner_product with lines title "MTL", \
      peak_scalar_add with linespoint '+' title "peak Add", \
      peak_scalar_mul with linespoint '*' title "peak Mul"
pause (1);
gset terminal png small color;
replot;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% plot vector addition operation benchmark
gset output "bench_matrix_vector_product.png";
gset terminal x11
title("matrix vector multiply");
gplot [x_lo:x_up][y_lo:y_up] \
      tvmet_matrix_vector_product with lines title "tvmet", \
      ublas_matrix_vector_product with lines title "uBLAS", \
      mtl_matrix_vector_product with lines title "MTL", \
      stl_matrix_vector_product with lines title "STL", \
      peak_scalar_add with linespoint '+' title "peak Add", \
      peak_scalar_mul with linespoint '*' title "peak Mul"
pause (1);
gset terminal png small color;
replot;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% plot vector addition operation benchmark
gset output "bench_matrix_matrix_product.png";
gset terminal x11
title("matrix matrix multiply");
gplot [x_lo:x_up][y_lo:y_up] \
      tvmet_matrix_matrix_product with lines title "tvmet", \
      ublas_matrix_matrix_product with lines title "uBLAS", \
      mtl_matrix_matrix_product with lines title "MTL", \
      stl_matrix_matrix_product with lines title "STL", \
      peak_scalar_add with linespoint '+' title "peak Add", \
      peak_scalar_mul with linespoint '*' title "peak Mul"
pause (1);
gset terminal png small color;
replot;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% plot daxpy benchmark
gset output "bench_daxpy.png";
gset terminal x11
title("Fortran's DAXPY");
gplot [x_lo:x_up][y_lo:y_up] \
      tvmet_axpy with lines title "tvmet", \
      ublas_axpy with lines title "uBLAS", \
      mtl_axpy with lines title "MTL", \
      stl_axpy with lines title "STL", \
      peak_scalar_add with linespoint '+' title "peak Add", \
      peak_scalar_mul with linespoint '*' title "peak Mul"
pause (1);
gset terminal png small color;
replot;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
gset terminal x11
closeplot;
