/*
 * Tiny Vector Matrix Library
 * Dense Vector Matrix Libary of Tiny size using Expression Templates
 *
 * Copyright (C) 2001 - 2003 Olaf Petzold <opetzold@wit.regiocom.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: peak.h,v 1.3 2003/02/08 23:14:01 opetzold Exp $
 */

#ifndef TVMET_BENCHMARK_PEAK_H
#define TVMET_BENCHMARK_PEAK_H

/*
 * \class Interface<interface_peak_tag, class T, std::size_t Sz>
 * \brief Implementation details for peak measurements, completly different from
 * other Interfaces!
 */
template<class T, std::size_t Sz>
class Interface<interface_peak_tag, T, Sz>
{
private:
  class Null { };

public:
  typedef T							value_type;

  typedef Null							matrix_type;
  typedef Null							vector_type;

  /** The name of the libary. */
  static inline std::string name() { return "peak"; }

public:

  /** Fill the given container. */
  static inline void random_fill(T& c, T min, T max)
  {
    c = min + static_cast<T>( max * std::rand()/(RAND_MAX + min) );
  }

public: // benchmark math implementions

  /** What's implemented here. */
  struct implements {
    enum {
      vector_add = false,
      vector_inner_product = false,
      vector_outer_product = false,
      matrix_vector_product = false,
      matrix_matrix_product = false,
      axpy = false,

      scalar_add = true,
      scalar_mul = true
    };
  };

public: // peak benchmark implementation

  /** Scalar addition */
  static inline void scalar_add(T& s)
  {
    s += T(0);
  }

  /** Scalar multiply */
  static inline void scalar_mul(T& s)
  {
    s *= T(1);
  }

};

#endif /* TVMET_BENCHMARK_PEAK_H */

// Local Variables:
// mode:C++
// End:
